@@ -36,38 +36,53 @@ class AdminPlaceholderTag(Tag):
     )
     
     def render_tag(self, context, name, extra_bits, nodelist=None):
-        fromUrl = context['request'].path_info
+        page = context['current_page']
+        
         if nodelist:
             text = nodelist.render(context)
         else:
             text = ''
+            
         obj, created = AdminPlaceholder.objects.get_or_create(
             name=name,
-            fromUrl=fromUrl,
+            page=page,
             defaults={'text': text,},
         )
         
+        if obj.useGlobalAdminPlaceholder:
+            obj, created = AdminPlaceholder.objects.get_or_create(
+                name=name,
+                page=None,
+                defaults={'text': '',},
+            )
+        
         return obj.text
         
 class BlockDisplayControlTag(Tag):
-    name = 'with'
+    name = 'blockDisplayControlTag'
     options = Options(
         Argument('name'),
         blocks=[('endBlockDisplayControl', 'nodelist')],
     )
 
     def render_tag(self, context, name, nodelist):
-        fromUrl = context['request'].path_info
-        
+        page = context['current_page']
         obj, created = BlockDisplayControl.objects.get_or_create(
             name=name,
-            fromUrl=fromUrl,
+            page=page,
         )
         
+        if obj.useGlobalBlockDisplayControl:
+            obj, created = BlockDisplayControl.objects.get_or_create(
+                name=name,
+                page=None,
+            )
+        
         if obj.display:
             text = nodelist.render(context)
         else:
             text = ''
+        
         return text
 
 register.tag('blockDisplayControl', BlockDisplayControlTag) 
